@@ -9,9 +9,12 @@ our @EXPORT = (qw(run));
 
 use Getopt::Long;
 
+use Exception::Class;
+
 use XML::Grammar::Fiction::FromProto;
 use XML::Grammar::Fiction::FromProto::Parser::QnD;
 
+
 =head1 NAME
 
 XML::Grammar::Fiction::App::FromProto - command line app-in-a-module
@@ -19,11 +22,11 @@ to convert from a well-formed plaintext format to Fiction-XML.
 
 =head1 VERSION
 
-Version 0.0.3
+Version 0.1.0
 
 =cut
 
-our $VERSION = '0.0.3';
+our $VERSION = '0.1.0';
 
 =head1 SYNOPSIS
 
@@ -55,15 +58,50 @@ sub run
         parser_class => "XML::Grammar::Fiction::FromProto::Parser::QnD",
     });
 
-    my $output_xml = $converter->convert({
-            source => { file => shift(@ARGV), },
-        }
-    );
+    eval {
+        my $output_xml = $converter->convert({
+                source => { file => shift(@ARGV), },
+            }
+        );
 
-    open my $out, ">", $output_filename;
-    binmode $out, ":utf8";
-    print {$out} $output_xml;
-    close($out);
+        open my $out, ">", $output_filename;
+        binmode $out, ":utf8";
+        print {$out} $output_xml;
+        close($out);
+    };
+
+    # Error handling.
+
+    my $e;
+    if ($e = Exception::Class->caught("XML::Grammar::Fiction::Err::Parse::TagsMismatch"))
+    {
+        warn $e->error(), "\n";
+        warn "Open: ", $e->opening_tag->name(), 
+            " at line ", $e->opening_tag->line(), "\n"
+            ;
+        warn "Close: ", 
+            $e->closing_tag->name(), " at line ", 
+            $e->closing_tag->line(), "\n";
+
+        exit(-1);
+    }
+    elsif ($e = Exception::Class->caught("XML::Grammar::Fiction::Err::Parse::LineError"))
+    {
+        warn $e->error(), "\n";
+        warn "At line ", $e->line(), "\n";
+        exit(-1);
+    }
+    elsif ($e = Exception::Class->caught())
+    {
+        if (ref($e))
+        {
+            $e->rethrow();
+        }
+        else
+        {
+            die $e;
+        }
+    }
 
     exit(0);
 }
