@@ -3,9 +3,7 @@ package XML::Grammar::Fiction::FromProto::Parser;
 use strict;
 use warnings;
 
-use base 'XML::Grammar::Fiction::Base';
-
-1;
+use Moose;
 
 =head1 NAME
 
@@ -16,11 +14,11 @@ B<For internal use only>.
 
 =head1 VERSION
 
-Version 0.0.3
+Version 0.1.0
 
 =cut
 
-our $VERSION = '0.0.3';
+our $VERSION = '0.1.0';
 
 =head1 AUTHOR
 
@@ -43,3 +41,6 @@ Copyright 2007 Shlomi Fish, all rights reserved.
 This program is released under the following license: MIT X11.
 
 =cut
+
+1;
+
